==> haskell-sandi-0.3.6-9-armv7h.pkg.tar.xz: usr/share/haskell/haskell-sandi/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: sandi
version: 0.3.6
id: sandi-0.3.6-e6f8f3dc4e2dd67c805ed530b117bcca
key: sandi_F9Q092eDRiPJIdwViNWtBG
license: BSD3
copyright: Magnus Therning, 2012
maintainer: magnus@therning.org
homepage: http://hackage.haskell.org/package/sandi
synopsis: Data encoding library
description:
    Reasonably fast data encoding library.
category: Codec Conduit
author: Magnus Therning
exposed: True
exposed-modules:
    Codec.Binary.Base16 Codec.Binary.Base32 Codec.Binary.Base32Hex
    Codec.Binary.Base64 Codec.Binary.Base64Url Codec.Binary.Base85
    Codec.Binary.QuotedPrintable Codec.Binary.Uu Codec.Binary.Xx
    Codec.Binary.Yenc Data.Conduit.Codec.Base16
    Data.Conduit.Codec.Base32 Data.Conduit.Codec.Base32Hex
    Data.Conduit.Codec.Base64 Data.Conduit.Codec.Base64Url
    Data.Conduit.Codec.Base85 Data.Conduit.Codec.QuotedPrintable
    Data.Conduit.Codec.Uu Data.Conduit.Codec.Xx Data.Conduit.Codec.Yenc
hidden-modules: Data.Conduit.Codec.Util
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/sandi-0.3.6
library-dirs: /usr/lib/ghc-7.10.3/site-local/sandi-0.3.6
data-dir: /usr/share/arm-linux-ghc-7.10.3/sandi-0.3.6
hs-libraries: HSsandi-0.3.6-F9Q092eDRiPJIdwViNWtBG
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    conduit-1.2.6.3-0e2837c15036cd2e0c379e7f893dd487
    exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
haddock-interfaces: /usr/share/doc/haskell-sandi/html/sandi.haddock
haddock-html: /usr/share/doc/haskell-sandi/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sandi-0.3.6-10-armv7h.pkg.tar.xz: usr/share/haskell/haskell-sandi/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: sandi
version: 0.3.6
id: sandi-0.3.6-8ad04c1b87ad23f7840d19dbd0642a7c
key: sandi_KLswb1xnZ4R6WQqzcUNQ7c
license: BSD3
copyright: Magnus Therning, 2012
maintainer: magnus@therning.org
homepage: http://hackage.haskell.org/package/sandi
synopsis: Data encoding library
description:
    Reasonably fast data encoding library.
category: Codec Conduit
author: Magnus Therning
exposed: True
exposed-modules:
    Codec.Binary.Base16 Codec.Binary.Base32 Codec.Binary.Base32Hex
    Codec.Binary.Base64 Codec.Binary.Base64Url Codec.Binary.Base85
    Codec.Binary.QuotedPrintable Codec.Binary.Uu Codec.Binary.Xx
    Codec.Binary.Yenc Data.Conduit.Codec.Base16
    Data.Conduit.Codec.Base32 Data.Conduit.Codec.Base32Hex
    Data.Conduit.Codec.Base64 Data.Conduit.Codec.Base64Url
    Data.Conduit.Codec.Base85 Data.Conduit.Codec.QuotedPrintable
    Data.Conduit.Codec.Uu Data.Conduit.Codec.Xx Data.Conduit.Codec.Yenc
hidden-modules: Data.Conduit.Codec.Util
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/sandi-0.3.6
library-dirs: /usr/lib/ghc-7.10.3/site-local/sandi-0.3.6
data-dir: /usr/share/arm-linux-ghc-7.10.3/sandi-0.3.6
hs-libraries: HSsandi-0.3.6-KLswb1xnZ4R6WQqzcUNQ7c
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
    exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
haddock-interfaces: /usr/share/doc/haskell-sandi/html/sandi.haddock
haddock-html: /usr/share/doc/haskell-sandi/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
